# Generated by Django 4.1.7 on 2023-05-29 11:49

import uuid

import django.contrib.postgres.fields.hstore
import django.core.validators
import django.db.models.deletion
import enumfields.fields
from django.db import migrations, models

import arkindex.documents.dates
import arkindex.documents.models
import arkindex.project.aws
import arkindex.project.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AllowedMetaData',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('type', enumfields.fields.EnumField(enum=arkindex.documents.models.MetaType, max_length=50)),
                ('name', models.CharField(max_length=250)),
            ],
            options={
                'ordering': ('corpus', 'type', 'name'),
            },
        ),
        migrations.CreateModel(
            name='Classification',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('high_confidence', models.BooleanField(default=False)),
                ('state', enumfields.fields.EnumField(db_index=True, default='pending', enum=arkindex.documents.models.ClassificationState, max_length=16)),
                ('confidence', models.FloatField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Corpus',
            fields=[
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=250)),
                ('description', models.TextField(default='')),
                ('public', models.BooleanField(default=False)),
                ('indexable', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name_plural': 'corpora',
            },
        ),
        migrations.CreateModel(
            name='CorpusExport',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('state', enumfields.fields.EnumField(default='created', enum=arkindex.documents.models.CorpusExportState, max_length=10)),
            ],
            options={
                'abstract': False,
            },
            bases=(arkindex.project.aws.S3FileMixin, models.Model),
        ),
        migrations.CreateModel(
            name='Element',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('name', models.CharField(max_length=250)),
                ('polygon', arkindex.project.fields.LinearRingField(blank=True, null=True, srid=0)),
                ('rotation_angle', models.SmallIntegerField(default=0, help_text='Clockwise rotation to apply to the image after cropping, in degrees.', validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(359)])),
                ('mirrored', models.BooleanField(default=False, help_text='Mirror the image along the vertical axis before rotating.')),
                ('confidence', models.FloatField(blank=True, null=True, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(1)])),
            ],
        ),
        migrations.CreateModel(
            name='ElementPath',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('path', arkindex.project.fields.ArrayField(base_field=models.UUIDField(), size=None)),
                ('ordering', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='ElementType',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('slug', models.SlugField()),
                ('display_name', models.CharField(max_length=250)),
                ('folder', models.BooleanField(default=False)),
                ('indexable', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Entity',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.TextField()),
                ('metas', django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True)),
                ('validated', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name_plural': 'Entities',
            },
        ),
        migrations.CreateModel(
            name='EntityLink',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
            ],
        ),
        migrations.CreateModel(
            name='EntityRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('parent_name', models.CharField(max_length=250)),
                ('child_name', models.CharField(max_length=250)),
            ],
        ),
        migrations.CreateModel(
            name='EntityType',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=250)),
                ('color', models.CharField(default='ff0000', max_length=6)),
            ],
        ),
        migrations.CreateModel(
            name='MetaData',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=250)),
                ('type', enumfields.fields.EnumField(db_index=True, enum=arkindex.documents.models.MetaType, max_length=50)),
                ('value', models.TextField()),
            ],
            options={
                'ordering': ('element', 'name', 'id'),
            },
            bases=(arkindex.documents.dates.InterpretedDateMixin, models.Model),
        ),
        migrations.CreateModel(
            name='MLClass',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=1024)),
            ],
            options={
                'verbose_name_plural': 'classes',
                'ordering': ('corpus', 'name'),
            },
        ),
        migrations.CreateModel(
            name='Selection',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
            ],
        ),
        migrations.CreateModel(
            name='Transcription',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('text', models.TextField()),
                ('orientation', enumfields.fields.EnumField(default='horizontal-lr', enum=arkindex.documents.models.TextOrientation, max_length=50)),
                ('confidence', models.FloatField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='TranscriptionEntity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('offset', models.PositiveIntegerField()),
                ('length', models.PositiveIntegerField(validators=[django.core.validators.MinValueValidator(1)])),
                ('confidence', models.FloatField(blank=True, null=True, validators=[django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(1)])),
                ('entity', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcription_entities', to='documents.entity')),
                ('transcription', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcription_entities', to='documents.transcription')),
            ],
        ),
    ]
